<?php
/**
 * Simplified_Plugin
 *
 * @package   Simplified_Plugin
 * @author    Jacek Dobrowolski <jack@simplified.co>
 * @copyright 2022 Simplified
 * @license   GPL 2.0+
 * @link      https://simplified.com
 */

namespace Simplified_Plugin\Rest;

use Simplified_Plugin\Engine\Base;

/**
 * Example class for REST
 */
class Simplified extends Base {

	/**
	 * Initialize the class.
	 *
	 * @return void|bool
	 */
	public function initialize() {
		parent::initialize();

		\add_action( 'rest_api_init', array( $this, 'add_custom_stuff' ) );
	}

	/**
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function add_custom_stuff() {
		$this->add_custom_ruote();
	}


	/**
	 *
	 * @since 1.0.0
     *
     *  Make an instance of this class somewhere, then
     *  call this method and test on the command line with
     * `curl http://example.com/wp-json/simplified/v1/publish`
     * @return void
	 */
	public function add_custom_ruote() {

		\register_rest_route(
			'simplified/v1',
			'publish',
			array(
				'methods' => 'POST',
				'permission_callback' => function ($request) {
						return $request->get_header('Token') == \get_option(SIMPLONEAPP_PLUGIN_TEXTDOMAIN . '-api-token');
						},
				'callback'            => array( $this, 'publish_action' ),
				'args'                => array(
					'nonce' => array(
						'required' => false,
					),
				),
			)
		);

        \register_rest_route(
            'simplified/v1',
            'verify',
            array(
                'methods' => 'POST',
                'permission_callback' => function ($request) {
                    return $request->get_header('Token') == \get_option(SIMPLONEAPP_PLUGIN_TEXTDOMAIN . '-api-token');
                },
                'callback'            => array( $this, 'verify_action' ),
                'args'                => array(
                    'nonce' => array(
                        'required' => false,
                    ),
                ),
            )
        );
	}

	/**
	 * @since 1.0.0
	 * @param \WP_REST_Request $request Values.
	 * @return \WP_REST_Response|\WP_REST_Request
	 */
	public function publish_action( \WP_REST_Request $request ) {

		$params = $request->get_json_params();
		try {
			$this->validate_params($params);
		} catch (\Exception $e) {
			return new \WP_REST_Response(['error' => $e->getMessage()]);
		}
		$this->sanitize_params($params);
		$new_post = array(
			'post_title' => $params['title'],
			'post_content' => $params['content'],
			'post_status' => \get_option( SIMPLONEAPP_PLUGIN_TEXTDOMAIN . '-post-status' ),
			'post_date' => date('Y-m-d H:i:s'),
			'post_author' => \get_option(SIMPLONEAPP_PLUGIN_TEXTDOMAIN . '-user-id'),
			'post_type' => 'post',
			'post_category' => array(0)
		);
		$post_id = wp_insert_post($new_post);

		return new \WP_REST_Response(['ID' => $post_id]);
	}
    /**
     * @since 1.0.2
     * @param \WP_REST_Request $request Values.
     * @return \WP_REST_Response|\WP_REST_Request
     */
    public function verify_action( \WP_REST_Request $request ) {

        $return = [
            'message' => 'Plugin is installed',
            'url' => get_site_url(),
            'blog_name' => get_bloginfo('name')
        ];

        return new \WP_REST_Response(['success'=>true, 'data' => $return]);
    }
	private function validate_params(array $params): void
	{
		$allowedParams = ['title', 'content'];

		foreach ($params as $key => $param) {
			if (!in_array($key, $allowedParams)) {
				throw new \Exception('Parameter ' . $param . ' not allowed in request!');
			}
			if (!is_string($param)) {
				throw new \Exception('Parameter ' . $param . ' should be a string!');
			}
		}
	}

	private function sanitize_params(array &$params): void
	{
		$params['title'] = sanitize_title($params['title']);
		$params['content'] = wp_kses_post(sanitize_text_field($params['content']));
	}
}
